use async_trait::async_trait;
use sea_orm_migration::{prelude::*, schema::*};

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Oplogs::Table)
                    .if_not_exists()
                    .col(pk_auto(Oplogs::Id))
                    .col(string(Oplogs::Op))
                    .col(text(Oplogs::OpDesc))
                    .col(timestamp(Oplogs::OpAt))
                    .col(boolean_null(Oplogs::Result))
                    .col(text_null(Oplogs::ResultDesc))
                    .col(timestamp_null(Oplogs::ResultAt))
                    .to_owned())
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(
                Table::drop()
                    .table(Oplogs::Table)
                    .to_owned())
            .await
    }
}

#[derive(DeriveIden)]
enum Oplogs {
    Table,
    Id,
    Op,
    OpDesc,
    OpAt,
    Result,
    ResultDesc,
    ResultAt,
}
