use async_trait::async_trait;
use rocket::{fairing, Build, Rocket};
use rocket::fairing::AdHoc;
use sea_orm::DatabaseConnection;
pub use sea_orm_migration::prelude::*;
use sea_orm_rocket::Database;
use crate::api::Db;

mod m20241102_000001_create_nodes_table;
mod m20241102_000002_create_locks_table;
mod m20241103_000001_create_volumes_table;
mod m20250415_000001_create_oplog_table;

pub struct Migrator;

#[async_trait]
impl MigratorTrait for Migrator {
    fn migrations() -> Vec<Box<dyn MigrationTrait>> {
        vec![
            Box::new(m20241102_000001_create_nodes_table::Migration),
            Box::new(m20241102_000002_create_locks_table::Migration),
            Box::new(m20241103_000001_create_volumes_table::Migration),
            Box::new(m20250415_000001_create_oplog_table::Migration),
        ]
    }
}

async fn run_migrations(rocket: Rocket<Build>) -> fairing::Result {
    let conn = &Db::fetch(&rocket).unwrap().conn;
    let _ = Migrator::up(conn, None).await;
    Ok(rocket)
}

pub async fn run_migrations_unmanaged(conn: &DatabaseConnection) -> Result<(), DbErr> {
    Migrator::up(conn, None).await
}

pub(super) fn init() -> AdHoc {
    AdHoc::try_on_ignite("Applying migrations", run_migrations)
}
