use sea_orm::entity::prelude::*;
use sea_orm::sqlx::types::time::OffsetDateTime;
use serde::{Deserialize, Serialize};

pub enum Op {
    CreateLXC,
    ProvisionCarrier,
    TerminateCarrier,
    MigrateNode,
    CreateVolumeUnmanaged,
    MountVolume,
    UnmountVolume,
    RewriteConfigUnmount,
    DeleteVolume,
    TransferVolume,
}

impl Op {
    pub fn as_str(&self) -> &'static str {
        match self {
            Op::CreateLXC => "create-lxc",
            Op::ProvisionCarrier => "provision-carrier",
            Op::TerminateCarrier => "terminate-carrier",
            Op::MigrateNode => "migrate-node",
            Op::CreateVolumeUnmanaged => "create-volume-unmanaged",
            Op::MountVolume => "mount-volume",
            Op::UnmountVolume => "unmount-volume",
            Op::RewriteConfigUnmount => "rewrite-config-unmount",
            Op::DeleteVolume => "delete-volume",
            Op::TransferVolume => "transfer-volume",
        }
    }

    pub fn to_string(&self) -> String {
        self.as_str().to_string()
    }
}

#[derive(Clone, Debug, PartialEq, Eq, DeriveEntityModel, Deserialize, Serialize)]
#[sea_orm(table_name = "oplogs")]
pub struct Model {
    #[sea_orm(primary_key)]
    pub id: i64,
    pub op: String,
    pub op_desc: String,
    pub op_at: OffsetDateTime,
    pub result: Option<bool>,
    pub result_desc: Option<String>,
    pub result_at: Option<OffsetDateTime>,
}

#[derive(Copy, Clone, Debug, EnumIter, DeriveRelation)]
pub enum Relation {}

impl ActiveModelBehavior for ActiveModel {}
