use rocket::fairing::AdHoc;

pub mod db;
mod route;
pub mod util;
pub mod cluster;
pub mod entity;
use sea_orm_rocket::Database;
use db::Db;
use crate::api::entity::locks::ensure_vmid_lock;

pub mod services;

/** Perform any init-time operations that require the DB. */
pub fn post_init() -> AdHoc {
    AdHoc::on_liftoff("post_init", |rocket| Box::pin(async move {
        let conn = &Db::fetch(&rocket).unwrap().conn;
        ensure_vmid_lock(conn).await.unwrap();
    }))
}

pub fn init() -> AdHoc {
    AdHoc::on_ignite("mod(db)", |rocket| async {
        rocket.attach(db::init())
            .attach(route::init())
            .attach(post_init())
    })
}
